@@ -4,6 +4,7 @@
 #' @param trat Numeric vector with dependent variable.
 #' @param resp Numeric vector with independent variable.
 #' @param npar Number of model parameters (\emph{default} is  BC.4)
+#' @param sample.curve Provide the number of observations to simulate curvature (default is 1000)
 #' @param error Error bar (It can be SE - \emph{default}, SD or FALSE)
 #' @param ylab Variable response name (Accepts the \emph{expression}() function)
 #' @param xlab Treatments name (Accepts the \emph{expression}() function)
@@ -67,6 +68,7 @@
 BC=function(trat,
             resp,
             npar="BC.4",
+            sample.curve=1000,
             ylab="Dependent",
             xlab="Independent",
             theme=theme_classic(),
@@ -130,7 +132,7 @@ BC=function(trat,
                    ifelse(e <= 0, "+", "-"),
                    abs(e),
                    r2)
-  xp=seq(min(trat),max(trat),length.out = 1000)
+  xp=seq(min(trat),max(trat),length.out = sample.curve)
   preditos=data.frame(x=xp,
                       y=predict(mod,newdata = data.frame(trat=xp)))
   }
@@ -170,7 +172,7 @@ BC=function(trat,
                    ifelse(e <= 0, "+", "-"),
                    abs(e),
                    r2)
-  xp=seq(min(trat),max(trat),length.out = 1000)
+  xp=seq(min(trat),max(trat),length.out = sample.curve)
   preditos=data.frame(x=xp,
                       y=predict(mod,newdata = data.frame(trat=xp)))}
   if(is.na(comment)==FALSE){equation=paste(equation,"~\"",comment,"\"")}
@@ -215,7 +217,7 @@ BC=function(trat,
           legend.justification = 0)+
     ylab(ylab)+xlab(xlab)
   if(scale=="log"){graph=graph+scale_x_log10()}
-  temp1=seq(min(trat),max(trat),length.out=10000)
+  temp1=seq(min(trat),max(trat),length.out=sample.curve)
   result=predict(mod,newdata = data.frame(trat=temp1),
                  type="response")
   maximo=temp1[which.max(result)]
