@@ -5,6 +5,7 @@
 #' @description Degree 3 polynomial model without the beta 1 coefficient, with inverse beta3.
 #' @param trat Numeric vector with dependent variable.
 #' @param resp Numeric vector with independent variable.
+#' @param sample.curve Provide the number of observations to simulate curvature (default is 1000)
 #' @param ylab Dependent variable name (Accepts the \emph{expression}() function)
 #' @param xlab Independent variable name (Accepts the \emph{expression}() function)
 #' @param theme ggplot2 theme (\emph{default} is theme_classic())
@@ -38,6 +39,7 @@
 
 LM2i3=function(trat,
                resp,
+               sample.curve=1000,
                ylab="Dependent",
                error="SE",
                xlab="Independent",
@@ -91,7 +93,7 @@ LM2i3=function(trat,
                    media=media,
                    resp=media,
                    desvio)
-  xp=seq(min(trat),max(trat),length.out = 1000)
+  xp=seq(min(trat),max(trat),length.out = sample.curve)
   preditos=data.frame(x=xp,
                       y=predict(moda,newdata = data.frame(trat=xp)))
   x=preditos$x
@@ -132,7 +134,7 @@ LM2i3=function(trat,
   predesp=predict(moda)
   predobs=resp
   rmse=sqrt(mean((predesp-predobs)^2))
-  temp1=seq(min(trat),max(trat),length.out=5000)
+  temp1=seq(min(trat),max(trat),length.out=sample.curve)
   result=predict(moda,newdata = data.frame(trat=temp1),type="response")
   maximo=temp1[which.max(result)]
   respmax=result[which.max(result)]
