@@ -4,6 +4,7 @@
 #' @param trat Numeric vector with dependent variable.
 #' @param resp Numeric vector with independent variable.
 #' @param npar Number of parameters (mm2 or mm3)
+#' @param sample.curve Provide the number of observations to simulate curvature (default is 1000)
 #' @param ylab Variable response name (Accepts the \emph{expression}() function)
 #' @param xlab treatments name (Accepts the \emph{expression}() function)
 #' @param theme ggplot2 theme (\emph{default} is theme_bw())
@@ -44,6 +45,7 @@
 MM=function(trat,
             resp,
             npar="mm2",
+            sample.curve=1000,
             error="SE",
             ylab="Dependent",
             xlab="Independent",
@@ -99,7 +101,7 @@ MM=function(trat,
                    e,
                    xname.formula,
                    r2)
-  xp=seq(min(trat),max(trat),length.out = 1000)
+  xp=seq(min(trat),max(trat),length.out = sample.curve)
   preditos=data.frame(x=xp,
                       y=predict(mod,newdata = data.frame(trat=xp)))
   x=preditos$x
@@ -135,7 +137,7 @@ MM=function(trat,
                      e,
                      xname.formula,
                      r2)
-    xp=seq(min(trat),max(trat),length.out = 1000)
+    xp=seq(min(trat),max(trat),length.out = sample.curve)
     preditos=data.frame(x=xp,
                         y=predict(mod,newdata = data.frame(trat=xp)))
     x=preditos$x
@@ -174,7 +176,7 @@ MM=function(trat,
           legend.text.align = 0,
           legend.justification = 0)+
     ylab(ylab)+xlab(xlab)
-  temp1=seq(min(trat),max(trat),length.out=10000)
+  temp1=seq(min(trat),max(trat),length.out=sample.curve)
   result=predict(mod,newdata = data.frame(trat=temp1),type="response")
   maximo=temp1[which.max(result)]
   respmax=result[which.max(result)]
