@@ -11,6 +11,8 @@
 #' @param theme ggplot2 theme (\emph{default} is theme_classic())
 #' @param legend.position legend position (\emph{default} is "top")
 #' @param legend.text legend text
+#' @param legend.add.mean Add average in legend
+#' @param legend.add.mean.name Add media name
 #' @param point defines whether you want to plot all points ("all") or only the mean ("mean")
 #' @param textsize Font size
 #' @param pointsize	shape size
@@ -18,6 +20,7 @@
 #' @param add.line.mean Add line mean
 #' @param linesize	line size
 #' @param pointshape format point (default is 21)
+#' @param fontfamily Font family
 #' @return The function returns an exploratory graph of segments
 #' @keywords non-significant
 #' @export
@@ -35,6 +38,8 @@ Nreg=function(trat,
               theme=theme_classic(),
               legend.position="top",
               legend.text="not~significant",
+              legend.add.mean=TRUE,
+              legend.add.mean.name="hat(y)",
               width.bar=NA,
               point="all",
               textsize = 12,
@@ -42,7 +47,8 @@ Nreg=function(trat,
               add.line.mean=FALSE,
               linesize=0.8,
               pointsize = 4.5,
-              pointshape = 21){
+              pointshape = 21,
+              fontfamily="sans"){
   if(is.na(width.bar)==TRUE){width.bar=0.01*mean(trat)}
   requireNamespace("ggplot2")
   dados=data.frame(trat,resp)
@@ -58,6 +64,7 @@ Nreg=function(trat,
   temp1=dose
   result=media
   s=legend.text
+  if(legend.add.mean==TRUE){s=paste(legend.text,"~","(",legend.add.mean.name,"==",mean(media),")")}
   if(point=="mean"){
     grafico=ggplot(data1,aes(x=trat,y=resp))
     if(add.line==TRUE){grafico=grafico+geom_line(size=linesize)}
@@ -76,14 +83,14 @@ Nreg=function(trat,
     if(add.line.mean==TRUE){grafico=grafico+geom_hline(yintercept = mean(resp,na.rm=TRUE),lty=2)}
     grafico=grafico+
       geom_point(aes(color="black"),size=pointsize,shape=pointshape,fill="gray")}
-
+  if(add.line.mean==TRUE){result=mean(media)}
   grafico=grafico+theme+ylab(ylab)+xlab(xlab)+
     scale_color_manual(values="black",label=c(parse(text=s)),name="")+
     theme(text = element_text(size=textsize,color="black"),
-          axis.text = element_text(size=textsize,color="black"),
-          axis.title = element_text(size=textsize,color="black"),
+          axis.text = element_text(size=textsize,color="black",family = fontfamily),
+          axis.title = element_text(size=textsize,color="black",family = fontfamily),
           legend.position = legend.position,
-          legend.text=element_text(size=textsize),
+          legend.text=element_text(size=textsize,family = fontfamily),
           legend.direction = "vertical",
           legend.text.align = 0,
           legend.justification = 0)
