@@ -3,6 +3,7 @@
 #' @param trat Numeric vector with dependent variable.
 #' @param resp Numeric vector with independent variable.
 #' @param npar number of parameters (lo3 or lo4)
+#' @param sample.curve Provide the number of observations to simulate curvature (default is 1000)
 #' @param error Error bar (It can be SE - \emph{default}, SD or FALSE)
 #' @param ylab Variable response name (Accepts the \emph{expression}() function)
 #' @param xlab treatments name (Accepts the \emph{expression}() function)
@@ -43,6 +44,7 @@
 lorentz=function(trat,
                  resp,
                  npar = "lo3",
+                 sample.curve=1000,
                  ylab = "Dependent",
                  xlab = "Independent",
                  theme = theme_classic(),
@@ -140,8 +142,6 @@ lorentz=function(trat,
                                  e=coef(mod)[3]))
       r2=1-deviance(model1)/deviance(lm(ymean~1))}
 
-    # if(r2=="all"){r2=cor(resp, fitted(mod))^2}
-    # if(r2=="mean"){r2=cor(ymean, predict(mod,newdata=data.frame(trat=unique(trat))))^2}
     r2=floor(r2*100)/100
 
     equation=sprintf("~~~%s==frac(%0.3e,1 %s %0.3e(%s %s %0.3e)^2) ~~~~~ italic(R^2) == %0.2f",
@@ -186,8 +186,6 @@ lorentz=function(trat,
                                  e=coef(mod)[4]))
       r2=1-deviance(model1)/deviance(lm(ymean~1))}
 
-    # if(r2=="all"){r2=cor(resp, fitted(mod))^2}
-    # if(r2=="mean"){r2=cor(ymean, predict(mod,newdata=data.frame(trat=unique(trat))))^2}
     r2=floor(r2*100)/100
 
     equation=sprintf("~~~%s==%0.3e + frac(%0.3e,1 %s %0.3e(%s %s %0.3e)^2) ~~~~~ italic(R^2) == %0.2f",
@@ -201,7 +199,7 @@ lorentz=function(trat,
                      abs(e),
                      r2)
     if(is.na(comment)==FALSE){equation=paste(equation,"~\"",comment,"\"")}}
-  xp=seq(min(trat),max(trat),length.out = 1000)
+  xp=seq(min(trat),max(trat),length.out = sample.curve)
   preditos=data.frame(x=xp,
                       y=predict(mod,newdata = data.frame(trat=xp)))
   predesp=predict(mod)
@@ -236,7 +234,7 @@ lorentz=function(trat,
           legend.justification = 0)+
     ylab(ylab)+xlab(xlab)
   if(scale=="log"){graph=graph+scale_x_log10()}
-  temp1=seq(min(trat),max(trat),length.out=5000)
+  temp1=seq(min(trat),max(trat),length.out=sample.curve)
   result=predict(mod,newdata = data.frame(trat=temp1),type="response")
   maximo=temp1[which.max(result)]
   respmax=result[which.max(result)]
