@@ -5,6 +5,7 @@
 #' @description This function performs Valcam regression analysis.
 #' @param trat Numeric vector with dependent variable.
 #' @param resp Numeric vector with independent variable.
+#' @param sample.curve Provide the number of observations to simulate curvature (default is 1000)
 #' @param ylab Dependent variable name (Accepts the \emph{expression}() function)
 #' @param xlab Independent variable name (Accepts the \emph{expression}() function)
 #' @param theme ggplot2 theme (\emph{default} is theme_classic())
@@ -38,6 +39,7 @@
 
 valcam=function(trat,
                 resp,
+                sample.curve=1000,
                 error = "SE",
                 ylab = "Dependent",
                 xlab = "Independent",
@@ -98,7 +100,7 @@ valcam=function(trat,
                    xname.formula,
                    r2)
   if(is.na(comment)==FALSE){equation=paste(equation,"~\"",comment,"\"")}
-  xp=seq(min(trat),max(trat),length.out = 1000)
+  xp=seq(min(trat),max(trat),length.out = sample.curve)
   preditos=data.frame(x=xp,
                       y=predict(model,newdata = data.frame(trat=xp)))
   predesp=predict(model)
@@ -133,7 +135,7 @@ valcam=function(trat,
           legend.justification = 0)+
     ylab(ylab)+xlab(xlab)
   if(scale=="log"){graph=graph+scale_x_log10()}
-  temp1=seq(min(trat),max(trat),length.out=10000)
+  temp1=seq(min(trat),max(trat),length.out=sample.curve)
   result=predict(model,newdata = data.frame(trat=temp1),type="response")
   maximo=temp1[which.max(result)]
   respmax=result[which.max(result)]
