@@ -3,6 +3,7 @@
 #' This function performs regression analysis using the Yield loss model.
 #' @param trat Numeric vector with dependent variable.
 #' @param resp Numeric vector with independent variable.
+#' @param sample.curve Provide the number of observations to simulate curvature (default is 1000)
 #' @param ylab Variable response name (Accepts the \emph{expression}() function)
 #' @param xlab treatments name (Accepts the \emph{expression}() function)
 #' @param theme ggplot2 theme (\emph{default} is theme_bw())
@@ -38,6 +39,7 @@
 
 yieldloss=function(trat,
             resp,
+            sample.curve=1000,
             error="SE",
             ylab="Dependent",
             xlab="Independent",
@@ -119,7 +121,7 @@ yieldloss=function(trat,
                      bc,
                      xname.formula,
                      r2)
-    xp=seq(min(trat),max(trat),length.out = 1000)
+    xp=seq(min(trat),max(trat),length.out = sample.curve)
     preditos=data.frame(x=xp,
                         y=predict(mod,newdata = data.frame(trat=xp)))
     x=preditos$x
@@ -151,7 +153,7 @@ yieldloss=function(trat,
           legend.justification = 0)+
     ylab(ylab)+xlab(xlab)
   if(scale=="log"){graph=graph+scale_x_log10()}
-  temp1=seq(min(trat),max(trat),length.out=10000)
+  temp1=seq(min(trat),max(trat),length.out=sample.curve)
   result=predict(mod,newdata = data.frame(trat=temp1),type="response")
   aic=AIC(mod)
   bic=BIC(mod)
